@@ -35,6 +35,11 @@ class Command(BaseCommand):
             default=False,
             help='Tells Django to use plain Python, not BPython nor IPython.'
         )
+        parser.add_argument(
+            '--idle', action='store_true', dest='idle',
+            default=False,
+            help='Tells Django to use Idle.'
+        )
         parser.add_argument(
             '--bpython', action='store_true', dest='bpython',
             default=False,
@@ -179,7 +184,7 @@ class Command(BaseCommand):
         no_browser = options['no_browser']
 
         def install_kernel_spec(app, display_name, ipython_arguments):
-            """install an IPython >= 3.0 kernelspec that loads django extensions"""
+            """Install an IPython >= 3.0 kernelspec that loads django extensions"""
             ksm = app.kernel_spec_manager
             try_spec_names = getattr(settings, 'NOTEBOOK_KERNEL_SPEC_NAMES', [
                 'python3' if PY3 else 'python2',
@@ -368,8 +373,27 @@ class Command(BaseCommand):
                   vi_mode=options['vi_mode'], configure=run_config)
         return run_ptipython
 
+    def get_idle(self, options):
+        from idlelib.pyshell import main
+
+        def run_idle():
+            sys.argv = [
+                sys.argv[0],
+                '-c',
+                """
+from django_extensions.management import shells
+from django.core.management.color import no_style
+for k, m in shells.import_objects({}, no_style()).items():
+    globals()[k] = m
+""",
+            ]
+            main()
+
+        return run_idle
+
     def set_application_name(self, options):
-        """Set the application_name on PostgreSQL connection
+        """
+        Set the application_name on PostgreSQL connection
 
         Use the fallback_application_name to let the user override
         it with PGAPPNAME env variable
@@ -407,6 +431,7 @@ class Command(BaseCommand):
         use_ipython = options['ipython']
         use_bpython = options['bpython']
         use_plain = options['plain']
+        use_idle = options['idle']
         use_ptpython = options['ptpython']
         use_ptipython = options['ptipython']
         verbosity = options["verbosity"]
@@ -444,9 +469,10 @@ class Command(BaseCommand):
                     finally:
                         execution_time = time.time() - starttime
                         raw_sql = self.db.ops.last_executed_query(self.cursor, sql, params)
+                        if truncate:
+                            raw_sql = raw_sql[:truncate]
 
                         if sqlparse:
-                            raw_sql = raw_sql[:truncate]
                             raw_sql = sqlparse.format(raw_sql, **sqlparse_format_kwargs)
 
                         if pygments:
@@ -469,6 +495,7 @@ class Command(BaseCommand):
             ('bpython', self.get_bpython),
             ('ipython', self.get_ipython),
             ('plain', self.get_plain),
+            ('idle', self.get_idle),
         )
         SETTINGS_SHELL_PLUS = getattr(settings, 'SHELL_PLUS', None)
 
@@ -496,6 +523,9 @@ class Command(BaseCommand):
         elif use_ptipython:
             shell = self.get_ptipython(options)
             shell_name = "ptipython"
+        elif use_idle:
+            shell = self.get_idle(options)
+            shell_name = "idle"
         elif SETTINGS_SHELL_PLUS:
             shell_name = SETTINGS_SHELL_PLUS
             shell = dict(shells)[shell_name](options)
